summaryrefslogtreecommitdiffstats
path: root/src/part/radialMap/widget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/part/radialMap/widget.cpp')
-rw-r--r--src/part/radialMap/widget.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/part/radialMap/widget.cpp b/src/part/radialMap/widget.cpp
index fd8ff14..e1b606f 100644
--- a/src/part/radialMap/widget.cpp
+++ b/src/part/radialMap/widget.cpp
@@ -46,11 +46,11 @@ RadialMap::Widget::url( File const * const file ) const
}
void
-RadialMap::Widget::tqinvalidate( const bool b )
+RadialMap::Widget::invalidate( const bool b )
{
if( isValid() )
{
//**** have to check that only way to tqinvalidate is this function frankly
//**** otherwise you may get bugs..
//disable mouse tracking
@@ -65,7 +65,7 @@ RadialMap::Widget::tqinvalidate( const bool b )
//FIXME move this disablement thing no?
// it is confusing in other areas, like the whole createFromCache() thing
- m_map.tqinvalidate( b ); //b signifies whether the pixmap is made to look disabled or not
+ m_map.invalidate( b ); //b signifies whether the pixmap is made to look disabled or not
if( b )
update();
@@ -77,10 +77,10 @@ RadialMap::Widget::tqinvalidate( const bool b )
void
RadialMap::Widget::create( const Directory *tree )
{
//it is not the responsibility of create() to tqinvalidate first
//skip invalidation at your own risk
//FIXME make it the responsibility of create to tqinvalidate first
if( tree )
{
@@ -102,8 +102,8 @@ RadialMap::Widget::create( const Directory *tree )
void
RadialMap::Widget::createFromCache( const Directory *tree )
{
- //no scan was necessary, use cached tree, however we MUST still emit tqinvalidate
- tqinvalidate( false );
+ //no scan was necessary, use cached tree, however we MUST still emit invalidate
+ invalidate( false );
create( tree );
}
@@ -46,11 +46,11 @@ RadialMap::Widget::url( File const * const file ) const
if( isValid() )
{
- //**** have to check that only way to tqinvalidate is this function frankly
+ //**** have to check that only way to invalidate is this function frankly
//**** otherwise you may get bugs..
//disable mouse tracking
@@ -77,10 +77,10 @@ RadialMap::Widget::tqinvalidate( const bool b )
RadialMap::Widget::create( const Directory *tree )
{
- //it is not the responsibility of create() to tqinvalidate first
+ //it is not the responsibility of create() to invalidate first
//skip invalidation at your own risk
@@ -77,10 +77,10 @@ RadialMap::Widget::tqinvalidate( const bool b )
//skip invalidation at your own risk
- //FIXME make it the responsibility of create to tqinvalidate first
+ //FIXME make it the responsibility of create to invalidate first
if( tree )
{